@@ -65,7 +65,7 @@ class ToyModel:
                             "propensities_to_write": propensities_to_write,
                         }
         
-        with open(f'{os.path.abspath(__file__.replace(f"{str(os.path.basename(__file__))}", ""))}/.assembler_mold.py') as f:
+        with open(f'{os.path.abspath(__file__.replace(f"{str(os.path.basename(__file__))}", ""))}/assembler_mold.py') as f:
             gillespie_str = f.read().format(**replacements)
         return gillespie_str
 
@@ -77,10 +77,30 @@ class ToyModel:
 
         else:
             os.mkdir('./output/')
-            
+        
         with open(f'./output/{self.toy_name}.py', 'w') as f:
             f.writelines(
                 f"{data}")
+        
+        if os.path.exists('./output/__init__.py'):
+            with open('./output/__init__.py', 'r') as f:
+                lines = f.readlines()
+                f.close()
+                new_to_import = f"from {self.toy_name} import *"
+                line_in_file = False
+                
+                for line in lines:
+                    line_in_file = True if line == new_to_import else False
+                
+                if line_in_file == True:
+                    pass
+                else:
+                    with open('./output/__init__.py', 'a') as f:
+                        f.write(f'\nfrom {self.toy_name} import *')
+            
+        else:
+            with open('./output/__init__.py', 'w') as f:
+                f.write(f'from {self.toy_name} import *')
 
 if __name__ =='__main__':
     
